@@ -31,7 +31,7 @@
 
 #include <set>
 
-#include <math.h>
+#include <util/misc/math.h>
 
 #include <util/misc/formio.h>
 #include <util/state/stateio.h>
