@@ -35,9 +35,13 @@
 
 #include <chemistry/qc/scf/linkage.h>
 
+namespace sc {
+
 static ForceLink<MBPT2> mbpt_force_link_a_;
 static ForceLink<MP2BasisExtrap> mbpt_force_link_b_;
 
+}
+
 #endif /* __PIC__ */
 
 #endif
