@@ -37,6 +37,10 @@
 #include <math/scmat/local.h>
 #include <math/isosurf/volume.h>
 
+#ifndef M_LN2
+#  define M_LN2 0.69314718055994530942
+#endif
+
 using namespace std;
 using namespace sc;
 
