@@ -33,6 +33,8 @@
 #include <scconfig.h>
 #endif
 
+#include <string>
+
 #include <stdlib.h>
 #include <string.h>
 #if defined(HAVE_DLFCN_H)
@@ -44,94 +46,12 @@
 #include <util/class/class.h>
 
 using namespace std;
+using namespace sc;
 
-AVLMap<ClassKey,ClassDescP>* ClassDesc::all_ = 0;
-AVLMap<type_info_key,ClassDescP>* ClassDesc::type_info_all_ = 0;
+std::map<std::string,ClassDescP>* ClassDesc::all_ = 0;
+std::map<type_info_key,ClassDescP>* ClassDesc::type_info_all_ = 0;
 char * ClassDesc::classlib_search_path_ = 0;
-AVLSet<ClassKey>* ClassDesc::unresolved_parents_ = 0;
-
-/////////////////////////////////////////////////////////////////
-
-ClassKey::ClassKey() :
-  classname_(0)
-{
-}
-
-ClassKey::ClassKey(const char* name):
-  classname_(::strcpy(new char[strlen(name)+1],name))
-{
-}
-
-ClassKey::ClassKey(const ClassKey& key)
-{
-  if (key.classname_) {
-      classname_ = ::strcpy(new char[strlen(key.classname_)+1],key.classname_);
-    }
-  else {
-      classname_ = 0;
-    }
-}
-
-ClassKey::~ClassKey()
-{
-  delete[] classname_;
-}
-
-ClassKey& ClassKey::operator=(const ClassKey& key)
-{
-  delete[] classname_;
-  if (key.classname_) {
-      classname_ = ::strcpy(new char[strlen(key.classname_)+1],key.classname_);
-    }
-  else {
-      classname_ = 0;
-    }
-  return *this;
-}
-
-int ClassKey::operator==(const ClassKey& ck) const
-{
-  return cmp(ck) == 0;
-}
-
-int ClassKey::operator<(const ClassKey& ck) const
-{
-  return cmp(ck) < 0;
-}
-
-int
-ClassKey::hash() const
-{
-  int r=0;
-  size_t i;
-
-  // Even numbered bytes make up the lower part of the hash index
-  for (i=0; i < ::strlen(classname_); i+=2) {
-      r ^= classname_[i];
-    }
-
-  // Odd numbered bytes make up the upper part of the hash index
-  for (i=1; i < ::strlen(classname_); i+=2) {
-      r ^= classname_[i]<<8;
-    }
-
-  return r;
-}
-
-int ClassKey::cmp(const ClassKey&ck) const
-{
-  if (!classname_) {
-      if (!ck.classname_) return 0;
-      return -1;
-    }
-  if (!ck.classname_) return 1;
-  return strcmp(classname_,ck.classname_);
-}
-
-char* ClassKey::name() const
-{
-  return classname_;
-}
+std::set<std::string>* ClassDesc::unresolved_parents_ = 0;
 
 /////////////////////////////////////////////////////////////////
 
@@ -203,7 +123,7 @@ ParentClasses::init(const char* parents)
           access = ParentClass::Private;
         }
       else {
-          ClassKey parentkey(token);
+          std::string parentkey(token);
           // if the parents class desc does not exist create a temporary
           // the temporary will be incorrect,because it does not have the
           // parent's parents
@@ -211,7 +131,7 @@ ParentClasses::init(const char* parents)
               ClassDesc *tmp_classdesc = new ClassDesc(token);
               ClassDesc::all()[parentkey] = tmp_classdesc;
               if (ClassDesc::unresolved_parents_ == 0) {
-                  ClassDesc::unresolved_parents_ = new AVLSet<ClassKey>;
+                  ClassDesc::unresolved_parents_ = new std::set<std::string>;
                 }
               ClassDesc::unresolved_parents_->insert(token);
             }
@@ -302,11 +222,11 @@ ClassDesc::ClassDesc(const type_info &ti,
                      )
 {
   if (!type_info_all_) {
-      type_info_all_ = new AVLMap<type_info_key,ClassDescP>;
+      type_info_all_ = new std::map<type_info_key,ClassDescP>;
     }
   type_info_key key(&ti);
   if (type_info_all_->find(key) != type_info_all_->end()) {
-      ExEnv::err() << node0 << indent
+      ExEnv::err0() << indent
                    << "ERROR: duplicate ClassDesc detected for class "
                    << name << " type_info name = " << ti.name() << endl;
       abort();
@@ -317,7 +237,7 @@ ClassDesc::ClassDesc(const type_info &ti,
 
   // test the version number to see if it is valid
   if (version <= 0) {
-      ExEnv::err() << "ERROR: ClassDesc ctor: version <= 0" << endl;
+      ExEnv::errn() << "ERROR: ClassDesc ctor: version <= 0" << endl;
       exit(1);
     }
 
@@ -345,7 +265,7 @@ ClassDesc::init(const char* name, int version,
 
   // make sure that the static members have been initialized
   if (!all_) {
-      all_ = new AVLMap<ClassKey,ClassDescP>;
+      all_ = new std::map<std::string,ClassDescP>;
       const char* tmp = getenv("LD_LIBRARY_PATH");
       if (tmp) {
           // Needed for misbehaving getenv's.
@@ -362,8 +282,8 @@ ClassDesc::init(const char* name, int version,
   ClassDesc *me = name_to_class_desc(name);
   int temp_copy_present = 0;
   if (me && me->version() != 0) {
-      ExEnv::err()
-          << node0 << indent
+      ExEnv::err0()
+          << indent
           << "ERROR: ClassDesc ctor: ClassDesc already initialized for "
           << name << endl;
       abort();
@@ -376,8 +296,8 @@ ClassDesc::init(const char* name, int version,
 
   if (!temp_copy_present && name_to_class_desc(name)) {
       // I wasn't in the list before, but am in it now
-      ExEnv::err()
-          << node0 << indent
+      ExEnv::err0()
+          << indent
           << "ERROR: ClassDesc ctor: inheritance loop detected for "
           << name << endl;
       abort();
@@ -385,13 +305,13 @@ ClassDesc::init(const char* name, int version,
 
   classname_ = ::strcpy(new char[strlen(name)+1],name);
 
-  ClassKey key(name);
+  std::string key(name);
 
   // let each of the parents know that this is a child
   for (int i=0; i<parents_.n(); i++) {
-      ClassKey parentkey(parents_[i].classdesc()->name());
+      std::string parentkey(parents_[i].classdesc()->name());
       if (!(*all_)[parentkey]->children_)
-        (*all_)[parentkey]->children_ = new AVLSet<ClassKey>;
+        (*all_)[parentkey]->children_ = new std::set<std::string>;
       // let the parents know about the child
       ((*all_)[parentkey]->children_)->insert(key);
     }
@@ -403,24 +323,24 @@ ClassDesc::init(const char* name, int version,
       (*all_)[key]->children_ = 0;
 
       if (!children_) {
-          ExEnv::err()
-              << node0 << indent
+          ExEnv::err0()
+              << indent
               << "ERROR: ClassDesc: inconsistency in initialization for "
-              << key.name()
+              << key
               << "--perhaps a duplicated CTOR call" << endl;
           abort();
         }
 
       // go thru the list of children and correct their
       // parent class descriptors
-      for (AVLSet<ClassKey>::iterator i=children_->begin();
+      for (std::set<std::string>::iterator i=children_->begin();
            i!=children_->end(); i++) {
           (*all_)[*i]->change_parent((*all_)[key],this);
         }
 
       delete (*all_)[key];
-      unresolved_parents_->remove(key);
-      if (unresolved_parents_->length() == 0) {
+      unresolved_parents_->erase(key);
+      if (unresolved_parents_->size() == 0) {
           delete unresolved_parents_;
           unresolved_parents_ = 0;
         }
@@ -432,18 +352,18 @@ ClassDesc::~ClassDesc()
 {
   // remove references to this class descriptor
   if (children_) {
-      for (AVLSet<ClassKey>::iterator i=children_->begin();
+      for (std::set<std::string>::iterator i=children_->begin();
            i!=children_->end(); i++) {
-          if (all_->contains(*i)) {
+          if (all_->find(*i) != all_->end()) {
               (*all_)[*i]->change_parent(this,0);
             }
         }
     }
   // delete this ClassDesc from the list of all ClassDesc's
-  ClassKey key(classname_);
-  all_->remove(key);
+  std::string key(classname_);
+  all_->erase(key);
   // if the list of all ClassDesc's is empty, delete it
-  if (all_->length() == 0) {
+  if (all_->size() == 0) {
       delete all_;
       all_ = 0;
       delete[] classlib_search_path_;
@@ -463,11 +383,11 @@ ClassDesc::class_desc(const type_info &ti)
   return (*type_info_all_)[type_info_key(&ti)];
 }
 
-AVLMap<ClassKey,ClassDescP>&
+std::map<std::string,ClassDescP>&
 ClassDesc::all()
 {
   if (!all_) {
-      ExEnv::err() << "ClassDesc::all(): all not initialized" << endl;
+      ExEnv::errn() << "ClassDesc::all(): all not initialized" << endl;
       abort();
     }
   return *all_;
@@ -476,7 +396,7 @@ ClassDesc::all()
 ClassDesc*
 ClassDesc::name_to_class_desc(const char* name)
 {
-  ClassKey key(name);
+  std::string key(name);
   if (all_->find(key) == all_->end()) return 0;
   return (*all_)[key];
 }
@@ -515,44 +435,44 @@ ClassDesc::change_parent(ClassDesc*oldcd,ClassDesc*newcd)
 void
 ClassDesc::list_all_classes()
 {
-  ExEnv::out() << "Listing all classes:" << endl;
-  for (AVLMap<ClassKey,ClassDescP>::iterator ind=all_->begin();
+  ExEnv::out0() << "Listing all classes:" << endl;
+  for (std::map<std::string,ClassDescP>::iterator ind=all_->begin();
        ind!=all_->end(); ind++) {
-      ClassDesc* classdesc = ind.data();
-      ExEnv::out() << "class " << classdesc->name() << endl;
+      ClassDesc* classdesc = ind->second;
+      ExEnv::out0() << "class " << classdesc->name() << endl;
       ParentClasses& parents = classdesc->parents_;
       if (parents.n()) {
-          ExEnv::out() << "  parents:";
+          ExEnv::out0() << "  parents:";
           for (int i=0; i<parents.n(); i++) {
               if (parents[i].is_virtual()) {
-                  ExEnv::out() << " virtual";
+                  ExEnv::out0() << " virtual";
                 }
               if (parents[i].access() == ParentClass::Public) {
-                  ExEnv::out() << " public";
+                  ExEnv::out0() << " public";
                 }
               else if (parents[i].access() == ParentClass::Protected) {
-                  ExEnv::out() << " protected";
+                  ExEnv::out0() << " protected";
                 }
               if (parents[i].classdesc() == 0) {
-                  ExEnv::err() << endl
+                  ExEnv::errn() << endl
                                << "ERROR: parent " << i
                                << " for " << classdesc->name()
                                << " is missing" << endl;
                   abort();
                 }
               const char *n = parents[i].classdesc()->name();
-              ExEnv::out() << " " << parents[i].classdesc()->name();
+              ExEnv::out0() << " " << parents[i].classdesc()->name();
             }
-          ExEnv::out() << endl;
+          ExEnv::out0() << endl;
         }
-      AVLSet<ClassKey>* children = classdesc->children_;
+      std::set<std::string>* children = classdesc->children_;
       if (children) {
-          ExEnv::out() << "  children:";
-          for (AVLSet<ClassKey>::iterator pind=children->begin();
+          ExEnv::out0() << "  children:";
+          for (std::set<std::string>::iterator pind=children->begin();
                pind!=children->end(); pind++) {
-              ExEnv::out() << " " << (*pind).name();
+              ExEnv::out0() << " " << (*pind);
             }
-          ExEnv::out() << endl;
+          ExEnv::out0() << endl;
         }
     }
 }
@@ -583,7 +503,7 @@ ClassDesc::load_class(const char* classname)
       char* filename = new char[strlen(dir) + 8 + 1];
       strcpy(filename,dir);
       strcat(filename,"/classes");
-      ExEnv::out() << "ClassDesc::load_class looking for \"" << filename << "\""
+      ExEnv::outn() << "ClassDesc::load_class looking for \"" << filename << "\""
            << endl;
       FILE* fp = fopen(filename, "r");
       delete[] filename;
@@ -598,9 +518,9 @@ ClassDesc::load_class(const char* classname)
                 }
               char* lib = strtok(buf," ");
               char* testclassname = strtok(0," ");
-              ExEnv::out() << "lib = \"" << lib << "\"" << endl;
+              ExEnv::outn() << "lib = \"" << lib << "\"" << endl;
               while(testclassname) {
-                  ExEnv::out() << "classname = \"" << testclassname << "\"" << endl;
+                  ExEnv::outn() << "classname = \"" << testclassname << "\"" << endl;
                   if (strcmp(testclassname,classname) == 0) {
                       // found it
                       char* libname = new char[strlen(lib) + strlen(dir) + 2];
@@ -618,25 +538,25 @@ ClassDesc::load_class(const char* classname)
                       // and load parents until nothing is left
 
                       // load the library
-                      ExEnv::out() << "loading \"" << libname << "\"" << endl;
+                      ExEnv::outn() << "loading \"" << libname << "\"" << endl;
                       dlopen(libname, RTLD_LAZY);
 
                       // load code for parents
                       while (unresolved_parents_
-                             && unresolved_parents_->length()) {
-                          load_class((*unresolved_parents_->begin()).name());
+                             && unresolved_parents_->size()) {
+                          load_class((*unresolved_parents_->begin()).c_str());
                         }
 
                       fclose(fp);
                       delete[] path;
                       // make sure it worked.
                       if (name_to_class_desc(classname) == 0) {
-                          ExEnv::err() << "load of \"" << classname << "\" from \""
+                          ExEnv::errn() << "load of \"" << classname << "\" from \""
                                << libname << "\" failed" << endl;
                           delete[] libname;
                           return -1;
                         }
-                      ExEnv::out() << "loaded \"" << classname << "\" from \""
+                      ExEnv::outn() << "loaded \"" << classname << "\" from \""
                            << libname << "\"" << endl;
                       delete[] libname;
                       return 0;
@@ -653,7 +573,7 @@ ClassDesc::load_class(const char* classname)
   delete[] path;
 #endif // HAVE_DLFCN_H
 
-  ExEnv::out() << "ClassDesc::load_class(\"" << classname << "\"): load failed"
+  ExEnv::outn() << "ClassDesc::load_class(\"" << classname << "\"): load failed"
        << endl
        << "Either \"" << classname << "\" is an invalid class name or the code"
        << endl
@@ -720,16 +640,10 @@ operator <<(ostream&o, const RefBase &ref)
 
 #ifdef EXPLICIT_TEMPLATE_INSTANTIATION
 
-template class EAVLMMapNode<ClassKey,AVLMapNode<ClassKey,ClassDescP> >;
-template class EAVLMMap<ClassKey,AVLMapNode<ClassKey,ClassDescP> >;
-template class AVLMapNode<ClassKey,ClassDescP>;
-template class AVLMap<ClassKey,ClassDescP>;
-
-template class EAVLMMapNode<ClassKey,AVLMapNode<ClassKey,int> >;
-template class EAVLMMap<ClassKey,AVLMapNode<ClassKey,int> >;
-template class AVLMapNode<ClassKey,int>;
-template class AVLMap<ClassKey,int>;
-template class AVLSet<ClassKey>;
+template class std::map<std::string,ClassDescP>;
+               
+template class std::map<std::string,int>;
+template class std::set<std::string>;
 
 #endif
 
