@@ -36,8 +36,12 @@
 #include <util/state/stateio.h>
 #include <util/container/array.h>
 
+namespace sc {
+
 SSB_ARRAY_dec(int);
 
+}
+
 #endif
 
 // Local Variables:
